@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
-/* gtksourcelanguagemanager.c
+/*
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2003-2007 - Paolo Maggi <paolo.maggi@polito.it>
@@ -29,8 +29,7 @@
 
 #include "gtksourcelanguage.h"
 #include "gtksourcelanguage-private.h"
-#include "gtksourceview-utils.h"
-#include "gtksourceview-i18n.h"
+#include "gtksourceutils-private.h"
 
 /**
  * SECTION:languagemanager
@@ -261,7 +260,7 @@ gtk_source_language_manager_set_search_path (GtkSourceLanguageManager *lm,
 	tmp = lm->priv->lang_dirs;
 
 	if (dirs == NULL)
-		lm->priv->lang_dirs = _gtk_source_view_get_default_dirs (LANGUAGE_DIR, TRUE);
+		lm->priv->lang_dirs = _gtk_source_utils_get_default_dirs (LANGUAGE_DIR);
 	else
 		lm->priv->lang_dirs = g_strdupv (dirs);
 
@@ -286,7 +285,7 @@ gtk_source_language_manager_get_search_path (GtkSourceLanguageManager *lm)
 	g_return_val_if_fail (GTK_SOURCE_IS_LANGUAGE_MANAGER (lm), NULL);
 
 	if (lm->priv->lang_dirs == NULL)
-		lm->priv->lang_dirs = _gtk_source_view_get_default_dirs (LANGUAGE_DIR, TRUE);
+		lm->priv->lang_dirs = _gtk_source_utils_get_default_dirs (LANGUAGE_DIR);
 
 	return (const gchar * const *)lm->priv->lang_dirs;
 }
@@ -355,9 +354,9 @@ ensure_languages (GtkSourceLanguageManager *lm)
 	lm->priv->language_ids = g_hash_table_new_full (g_str_hash, g_str_equal,
 							g_free, g_object_unref);
 
-	filenames = _gtk_source_view_get_file_list ((gchar **)gtk_source_language_manager_get_search_path (lm),
-						    LANG_FILE_SUFFIX,
-						    TRUE);
+	filenames = _gtk_source_utils_get_file_list ((gchar **)gtk_source_language_manager_get_search_path (lm),
+						     LANG_FILE_SUFFIX,
+						     TRUE);
 
 	for (l = filenames; l != NULL; l = l->next)
 	{
@@ -485,6 +484,7 @@ pick_langs_for_filename (GtkSourceLanguageManager *lm,
 			if (g_pattern_match_simple (*gptr, filename_utf8))
 			{
 				langs = g_slist_prepend (langs, lang);
+				break;
 			}
 		}
 
