@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
-/* gtksourcemark.c
+/*
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2007 - Johannes Schmid <jhs@gnome.org>
@@ -25,7 +25,6 @@
 #include "gtksourcemark.h"
 #include "gtksourcebuffer.h"
 #include "gtksourcebuffer-private.h"
-#include "gtksourceview-i18n.h"
 
 /**
  * SECTION:mark
