@@ -39,6 +39,10 @@ GSList *	_gtk_source_utils_get_file_list			(gchar       **path,
 G_GNUC_INTERNAL
 gint		_gtk_source_utils_string_to_int			(const gchar *str);
 
+G_GNUC_INTERNAL
+gint		_gtk_source_utils_int_to_string			(guint         value,
+								 const gchar **outstr);
+
 G_GNUC_INTERNAL
 gchar *		_gtk_source_utils_pango_font_description_to_css	(const PangoFontDescription *font_desc);
 
