@@ -94,7 +94,7 @@ compare_strv (const gchar **strv,
 	}
 	else
 	{
-		g_assert (strv == NULL);
+		g_assert_null (strv);
 	}
 }
 
@@ -104,7 +104,8 @@ check_scheme (GtkSourceStyleScheme  *scheme,
               const gchar           *expected_name,
               const gchar           *expected_description,
               const gchar          **expected_authors,
-              const gchar           *style_id)
+              const gchar           *style_id,
+              const gchar           *background_rgba)
 {
 	GtkSourceStyle *style;
 
@@ -114,7 +115,19 @@ check_scheme (GtkSourceStyleScheme  *scheme,
 	compare_strv ((const gchar **)gtk_source_style_scheme_get_authors (scheme), expected_authors);
 
 	style = gtk_source_style_scheme_get_style (scheme, style_id);
-	g_assert (GTK_SOURCE_IS_STYLE (style));
+	g_assert_true (GTK_SOURCE_IS_STYLE (style));
+
+	if (background_rgba != NULL)
+	{
+		gchar *background = NULL;
+
+		g_object_get (style,
+		              "background", &background,
+			      NULL);
+
+		g_assert_cmpstr (background_rgba, ==, background);
+		g_free (background);
+	}
 }
 
 static void
@@ -125,7 +138,11 @@ test_scheme_properties (TestFixture   *fixture,
 	const gchar *authors[] = { "Paolo Borelli", "John Doe", NULL};
 
 	scheme = gtk_source_style_scheme_manager_get_scheme (fixture->manager, "test");
-	check_scheme (scheme, "test", "Test", "Test color scheme", authors, "def:comment");
+
+	check_scheme (scheme, "test", "Test", "Test color scheme", authors, "def:comment", NULL);
+
+	/* Check that net-address remapped correctly to "underlined" */
+	check_scheme (scheme, "test", "Test", "Test color scheme", authors, "def:net-address", "#FFFFFF");
 }
 
 static void
@@ -140,12 +157,12 @@ test_named_color_alpha (TestFixture   *fixture,
 
 	/* Use these two semi private methods to compare a named color and a normal one */
 	res = _gtk_source_style_scheme_get_current_line_color (scheme, &color1);
-	g_assert (res);
+	g_assert_true (res);
 
 	res = _gtk_source_style_scheme_get_background_pattern_color (scheme, &color2);
-	g_assert (res);
+	g_assert_true (res);
 
-	g_assert (gdk_rgba_equal (&color1, &color2));
+	g_assert_true (gdk_rgba_equal (&color1, &color2));
 }
 
 int
